wsgi-oauth2
===========

.. image:: docs/_static/oauth2.png

This module provides a simple WSGI middleware that requires the user to
authenticate via the specific `OAuth 2.0`_ service, e.g., Facebook_, Google_,
GitHub_.

You can install the package via downloading from PyPI_:

.. code-block:: console

   $ pip install wsgi-oauth2

Read the documentation_ as well.

.. _OAuth 2.0: https://oauth.net/2/
.. _Facebook: https://www.facebook.com/
.. _Google: https://www.google.com/
.. _GitHub: https://github.com/
.. _PyPI: https://pypi.org/project/wsgi-oauth2/
.. _documentation: https://dahlia.github.io/wsgi-oauth2/

